@@ -11,12 +11,13 @@
 ################################################################################
 
 INSTALLER_NAME="Rootkit Hunter installer"
-INSTALLER_VERSION="1.2.17"
-INSTALLER_COPYRIGHT="Copyright 2003-2014, Michael Boelen"
+INSTALLER_VERSION="1.2.20"
+INSTALLER_COPYRIGHT="Copyright 2003-2017, Michael Boelen"
 INSTALLER_LICENSE="
 
-Under active development by the Rootkit Hunter project team. For reporting
-bugs, updates, patches, comments and questions see: rkhunter.sourceforge.net
+This software was developed by the Rootkit Hunter project team.
+For reporting bugs, patches, comments and questions, please go to:
+http://rkhunter.sourceforge.net
 
 Rootkit Hunter comes with ABSOLUTELY NO WARRANTY. This is free
 software, and you are welcome to redistribute it under the terms
@@ -24,10 +25,10 @@ of the GNU General Public License. See LICENSE for details.
 "
 
 APPNAME="rkhunter"
-APPVERSION="1.4.2"
+APPVERSION="1.4.4"
 RKHINST_OWNER="0:0"
-RKHINST_MODE_EX="0750"
-RKHINST_MODE_RW="0640"
+RKHINST_MODE_EX="0700"
+RKHINST_MODE_RW="0600"
 RKHINST_MODE_RWR="0644"
 RKHINST_LAYOUT="default"
 RKHINST_ACTION=""
@@ -92,6 +93,7 @@ showHelp() { # Show help / version
 	echo "                     (Default is to create a separate configuration file.)"
 	echo "  --show           : Show chosen layout."
 	echo "  --remove         : Uninstall according to chosen layout."
+	echo "  --uninstall      : Alias for the '--remove' option."
 	echo "  --version        : Show the installer version."
 	echo ""
 
@@ -731,8 +733,8 @@ doInstall()  {
 			fi
 		fi
 	done
-	umask 027
 
+	umask 077
 	for DIR in ${RKHINST_DIRS_EXCEP}; do
 		if [ -d "${DIR}" ]; then
 			if [ -w "${DIR}" ]; then
@@ -759,6 +761,7 @@ doInstall()  {
 			;;
 		esac
 	done
+	umask 027
 
 
 	#
@@ -835,11 +838,22 @@ doInstall()  {
 	# Language support files
 	ERRCODE=0
 
+	if [ -d "./files/i18n/CVS" ]; then
+		rm -rf "./files/i18n/CVS"
+	fi
+
 	for FILE in `find ./files/i18n -type f`; do
 		cp "${FILE}" "${RKHINST_LANG_DIR}" >/dev/null 2>&1
 		ERRCODE=$?
 
-		test $ERRCODE -ne 0 && break
+		FNAME=`echo ${FILE} | sed 's|^./files/i18n/||'`
+
+		if [ $ERRCODE -eq 0 ]; then
+			chmod "${RKHINST_MODE_RW}" "${RKHINST_LANG_DIR}/${FNAME}"
+		else
+			echo " Installing ${FILE}: FAILED: Code $ERRCODE"
+			break
+		fi
 	done
 
 	if [ $ERRCODE -eq 0 ];then
@@ -853,11 +867,22 @@ doInstall()  {
 	# ClamAV signatures
 	ERRCODE=0
 
+	if [ -d "./files/signatures/CVS" ]; then
+		rm -rf "./files/signatures/CVS"
+	fi
+
 	for FILE in `find ./files/signatures -type f`; do
 		cp "${FILE}" "${RKHINST_SIG_DIR}" >/dev/null 2>&1
 		ERRCODE=$?
 
-		test $ERRCODE -ne 0 && break
+		FNAME=`echo ${FILE} | sed 's|^./files/signatures/||'`
+
+		if [ $ERRCODE -eq 0 ]; then
+			chmod "${RKHINST_MODE_RW}" "${RKHINST_SIG_DIR}/${FNAME}"
+		else
+			echo " Installing ${FILE}: FAILED: Code $ERRCODE"
+			break
+		fi
 	done
 
 	if [ $ERRCODE -eq 0 ];then
@@ -940,7 +965,15 @@ doInstall()  {
 
 			if [ "$FILE" = "rkhunter.conf" ]; then
 				echo "USER_FILEPROP_FILES_DIRS=${RKHINST_ETC_DIR}/${FILE}" >>"${RKHINST_ETC_DIR}/${NEWFILE}"
-				test -f "${RKHINST_ETC_DIR}/${FILE}.local" && echo "USER_FILEPROP_FILES_DIRS=${RKHINST_ETC_DIR}/${FILE}.local" >>"${RKHINST_ETC_DIR}/${NEWFILE}"
+
+				if [ -f "${RKHINST_ETC_DIR}/${FILE}.local" ]; then
+					echo "USER_FILEPROP_FILES_DIRS=${RKHINST_ETC_DIR}/${FILE}.local" >>"${RKHINST_ETC_DIR}/${NEWFILE}"
+					chmod "${RKHINST_MODE_RW}" "${RKHINST_ETC_DIR}/${FILE}.local"
+				fi
+
+				if [ -d "${RKHINST_ETC_DIR}/rkhunter.d" ]; then
+					echo "USER_FILEPROP_FILES_DIRS=${RKHINST_ETC_DIR}/rkhunter.d/*.conf" >>"${RKHINST_ETC_DIR}/${NEWFILE}"
+				fi
 			fi
 
 			case "${RKHINST_LAYOUT}" in
@@ -961,6 +994,10 @@ doInstall()  {
 			if [ $ERRCODE -eq 0 ]; then
 				echo " Installing ${FILE}: OK"
 				chmod "${RKHINST_MODE_RW}" "${RKHINST_ETC_DIR}/${FILE}"
+
+				if [ -f "${RKHINST_ETC_DIR}/${FILE}.local" ]; then
+					chmod "${RKHINST_MODE_RW}" "${RKHINST_ETC_DIR}/${FILE}.local"
+				fi
 			else
 				echo " Installing ${FILE}: FAILED: Code $ERRCODE"
 				exit 1
@@ -1132,6 +1169,12 @@ doRemove()  {
 		echo ""
 		echo "Please remove any ${RKHINST_ETC_DIR}/${FILE}.* files manually."
 		echo ""
+
+		if [ -d "${RKHINST_ETC_DIR}/${FILE}.d" ]; then
+			echo ""
+			echo "Please remove any ${RKHINST_ETC_DIR}/${FILE}.d directory manually."
+			echo ""
+		fi
 	done
 
 
@@ -1267,7 +1310,7 @@ while [ $# -ge 1 ]; do
 			exit 1
 		fi
 		;;
-	--show | --remove | --install)
+	--show | --remove | --install | --uninstall)
 		RKHINST_ACTION_SEEN=1
 		RKHINST_ACTION=`echo "$1" | sed 's/-//g'`
 		;;
@@ -1294,7 +1337,7 @@ else
 	show)
 		showTemplate $RKHINST_LAYOUT
 		;;
-	remove)	# Clean active window
+	remove | uninstall)	# Clean active window
 		selectTemplate $RKHINST_LAYOUT
 		clear
 		doRemove
